@@ -618,7 +618,7 @@ class SignStatus(Atms):
 
         if self._status == 'Ok':
             stat_int = 3
-        elif self._status in ('Not Communicating', 'Unknown'):
+        elif self._status in ('Not Communicating', 'Unknown', 'Device Error'):
             stat_int = 6
         elif self._status == 'Not in Service':
             stat_int = 4
